Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2565)

Unified Diff: chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h

Issue 1539043002: Pull SecurityStateModel out into a component (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: unit test debugging Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h
diff --git a/chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h b/chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h
index 703d12e400f45e867582f1fe858c311df6b65b26..1c6eeb94927ff8066ad32a39a294fd8adc091978 100644
--- a/chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h
+++ b/chrome/browser/ui/cocoa/website_settings/website_settings_bubble_controller.h
@@ -6,9 +6,9 @@
#include "base/mac/scoped_nsobject.h"
#include "base/memory/scoped_ptr.h"
-#include "chrome/browser/ssl/security_state_model.h"
#import "chrome/browser/ui/cocoa/base_bubble_controller.h"
#include "chrome/browser/ui/website_settings/website_settings_ui.h"
+#include "components/security_state/security_state_model.h"
#include "content/public/browser/web_contents_observer.h"
class WebsiteSettingsUIBridge;
@@ -111,13 +111,15 @@ class WebsiteSettingsUIBridge : public content::WebContentsObserver,
// is the currently active window. |profile| points to the currently active
// profile. |web_contents| points to the WebContents that wraps the currently
// active tab. |url| is the GURL of the currently active
// tab. |security_info| is the |SecurityStateModel::SecurityInfo| of
// the connection to the website in the currently active tab.
- static void Show(gfx::NativeWindow parent,
- Profile* profile,
- content::WebContents* web_contents,
- const GURL& url,
- const SecurityStateModel::SecurityInfo& security_info);
+ static void Show(
+ gfx::NativeWindow parent,
+ Profile* profile,
+ content::WebContents* web_contents,
+ const GURL& url,
+ const security_state::SecurityStateModel::SecurityInfo& security_info);
void set_bubble_controller(
WebsiteSettingsBubbleController* bubble_controller);
@@ -111,13 +111,15 @@ class WebsiteSettingsUIBridge : public content::WebContentsObserver,
// profile. |web_contents| points to the WebContents that wraps the currently
// active tab. |url| is the GURL of the currently active
- // tab. |security_info| is the |SecurityStateModel::SecurityInfo| of
+ // tab. |security_info| is the
+ // |security_state::SecurityStateModel::SecurityInfo| of
// the connection to the website in the currently active tab.

Powered by Google App Engine
This is Rietveld 408576698